==> amarok_2.7.0.orig.tar.bz2: amarok-2.7.0/src/core-impl/collections/nepomukcollection/meta/NepomukArtist.cpp <==
/****************************************************************************************
 * Copyright (c) 2012 Phalgun Guduthur <me@phalgun.in>                                  *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "NepomukArtist.h"

#include "core/meta/Meta.h"

using namespace Meta;

NepomukArtist::NepomukArtist( const QString &name )
    : Meta::Artist()
    , m_name( name )
{
}

TrackList
NepomukArtist::tracks()
{
    return TrackList();
}

QString
NepomukArtist::name() const
{
    return m_name;
}

==> amarok-2.7.90.tar.bz2: amarok-2.7.90/src/core-impl/collections/nepomukcollection/meta/NepomukArtist.cpp <==
/****************************************************************************************
 * Copyright (c) 2012 Phalgun Guduthur <me@phalgun.in>                                  *
 * Copyright (c) 2013 Edward Toroshchin <amarok@hades.name>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "NepomukArtist.h"

#include "core/meta/Meta.h"

using namespace Meta;

NepomukArtist::NepomukArtist( const QUrl &resourceUri )
    : m_resource( resourceUri )
{
}

TrackList
NepomukArtist::tracks()
{
    return TrackList(); // TODO
}
